==> spip_3.0.21.orig.tar.xz: spip/plugins-dist/petitions/lang/petitions_da.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/petitions?lang_cible=da
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// F
	'form_pet_adresse_site' => 'Dit websteds URL', # MODIF
	'form_pet_aucune_signature' => 'Ingen signatur svarer til denne kode...', # MODIF
	'form_pet_confirmation' => 'Bekræft venligst din signatur:',
	'form_pet_deja_signe' => 'Du har allerede signeret denne tekst.',
	'form_pet_envoi_mail_confirmation' => 'En e-mail er netop sendt til dig som bekræftelse. Du bør gå ind på den URL, som er angivet i denne mail, for at bekræfte din signatur.', # MODIF
	'form_pet_mail_confirmation' => 'Goddag,

Du har ønsket at støtte denne appel:
@titre@.

Du at afgivet følgende oplysninger:
    Navn: @nom_email@
    Websted: @nom_site@ - @url_site@

VIGTIGT...
For at bekræfte din underskrift skal du blot klikke dig ind på
adressen nedenfor (ellers vil underskriften blive afvist):
    @url@

Tak for din deltagelse
', # MODIF
	'form_pet_nom_site2' => 'Navn på dit websted', # MODIF
	'form_pet_probleme_technique' => 'Teknisk problem: Appelfunktionen er i øjeblikket ude af drift.',
	'form_pet_signature_validee' => 'Din underskrift er godkendt. Den vil blive offentliggjort, når webstedet opdateres. Tak!',
	'form_pet_site_deja_enregistre' => 'Dette websted er allerede registreret',
	'form_pet_url_invalide' => 'Den URL, du har angivet, er ikke gyldig.',
	'form_pet_votre_email' => 'Din e-mail-adresse',
	'form_pet_votre_nom' => 'Dit navn eller alias', # MODIF
	'form_pet_votre_site' => 'Hvis du har et websted, kan du angive den nedenfor',

	// I
	'info_adresse_email' => 'EMAIL ADRESSE:',
	'info_site_web' => 'WEBSTED:',

	// L
	'lien_reponse_article' => 'Kommenter denne artikel'
);

?>

==> spip_3.1.4.orig.tar.xz: spip/plugins-dist/petitions/lang/petitions_da.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/petitions?lang_cible=da
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bouton_radio_activer_petition' => 'Tillad appeller',
	'bouton_radio_pas_petition' => 'Ingen appeller',
	'bouton_radio_petition_activee' => 'Appelfunktion slået til',
	'bouton_radio_supprimer_petition' => 'Slet appellen',

	// F
	'form_pet_adresse_site' => 'Dit websteds URL', # MODIF
	'form_pet_aucune_signature' => 'Ingen signatur svarer til denne kode...', # MODIF
	'form_pet_confirmation' => 'Bekræft venligst din signatur:',
	'form_pet_deja_signe' => 'Du har allerede signeret denne tekst.',
	'form_pet_envoi_mail_confirmation' => 'En e-mail er netop sendt til dig som bekræftelse. Du bør gå ind på den URL, som er angivet i denne mail, for at bekræfte din signatur.', # MODIF
	'form_pet_mail_confirmation' => 'Goddag,

Du har ønsket at støtte denne appel:
@titre@.

Du at afgivet følgende oplysninger:
    Navn: @nom_email@
    Websted: @nom_site@ - @url_site@

VIGTIGT...
For at bekræfte din underskrift skal du blot klikke dig ind på
adressen nedenfor (ellers vil underskriften blive afvist):
    @url@

Tak for din deltagelse
', # MODIF
	'form_pet_nom_site2' => 'Navn på dit websted', # MODIF
	'form_pet_probleme_technique' => 'Teknisk problem: Appelfunktionen er i øjeblikket ude af drift.',
	'form_pet_signature_validee' => 'Din underskrift er godkendt. Den vil blive offentliggjort, når webstedet opdateres. Tak!',
	'form_pet_site_deja_enregistre' => 'Dette websted er allerede registreret',
	'form_pet_url_invalide' => 'Den URL, du har angivet, er ikke gyldig.',
	'form_pet_votre_email' => 'Din e-mail-adresse',
	'form_pet_votre_nom' => 'Dit navn eller alias', # MODIF
	'form_pet_votre_site' => 'Hvis du har et websted, kan du angive den nedenfor',

	// I
	'info_adresse_email' => 'EMAIL ADRESSE:',
	'info_site_web' => 'WEBSTED:',

	// L
	'lien_reponse_article' => 'Kommenter denne artikel'
);

?>
